Characteristic

Enum Characteristic 

#[repr(u8)]
pub enum Characteristic {
Show 18 variants Forcedsubtitles = 0, Describesvideo = 1, Easytoread = 2, Framebased = 3, Mainprogram = 4, Originalcontent = 5, Voiceovertranslation = 6, Caption = 7, Subtitle = 8, Alternate = 9, Supplementary = 10, Commentary = 11, Dubbedtranslation = 12, Description = 13, Metadata = 14, Enhancedaudiointelligibility = 15, Emergency = 16, Karaoke = 17,
}

Variants



Forcedsubtitles = 0

Textual information meant for display when no other text representation is selected. It is used to clarify dialogue, alternate languages, texted graphics or location/person IDs that are not otherwise covered in the dubbed/localized audio.



Describesvideo = 1

Textual or audio media component containing a textual description (intended for audio synthesis) or an audio description describing a visual component



Easytoread = 2

Simplified or reduced captions as specified in [United States Code Title 47 CFR 79.103(c)(9)].



Framebased = 3

A media characteristic that indicates that a track selection option includes frame-based content.



Mainprogram = 4

Main media component(s) which is/are intended for presentation if no other information is provided



Originalcontent = 5

A media characteristic that indicates that a track or media selection option contains original content.



Voiceovertranslation = 6

A media characteristic that indicates that a track or media selection option contains a language translation and verbal interpretation of spoken dialog.



Caption = 7

Textual media component containing transcriptions of spoken dialog and auditory cues such as sound effects and music for the hearing impaired.



Subtitle = 8

Textual transcriptions of spoken dialog.



Alternate = 9

Textual media component containing transcriptions of spoken dialog and auditory cues such as sound effects and music for the hearing impaired.



Supplementary = 10

Media content component that is supplementary to a media content component of a different media component type.



Commentary = 11

Experience that contains a commentary (e.g. director’s commentary) (typically audio)



Dubbedtranslation = 12

Experience that contains an element that is presented in a different language from the original (e.g. dubbed audio, translated captions)



Description = 13

Textual or audio media component containing a textual description (intended for audio synthesis) or an audio description describing a visual component



Metadata = 14

Media component containing information intended to be processed by application specific elements.



Enhancedaudiointelligibility = 15

Experience containing an element for improved intelligibility of the dialogue.



Emergency = 16

Experience that provides information, about a current emergency, that is intended to enable the protection of life, health, safety, and property, and may also include critical details regarding the emergency and how to respond to the emergency.



Karaoke = 17

Textual representation of a songs’ lyrics, usually in the same language as the associated song as specified in [SMPTE ST 2067-2].

Implementations

Source

impl Characteristic

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value