#[repr(u8)]pub enum Status {
Success = 0,
Invalidstateforcommand = 1,
Notallowed = 2,
Notactive = 3,
Speedoutofrange = 4,
Seekoutofrange = 5,
}Variants
Success = 0
Succeeded
Invalidstateforcommand = 1
Requested playback command is invalid in the current playback state.
Notallowed = 2
Requested playback command is not allowed in the current playback state. For example, attempting to fast-forward during a commercial might return NotAllowed.
Notactive = 3
This endpoint is not active for playback.
Speedoutofrange = 4
The FastForward or Rewind Command was issued but the media is already playing back at the fastest speed supported by the server in the respective direction.
Seekoutofrange = 5
The Seek Command was issued with a value of position outside of the allowed seek range of the media.
Implementations